# Hopfield-NLMIP

[![Build Status](https://travis-ci.com/mathildebadoual/hmip.svg?token=sSNFwE8cjSB4sGxziMoY&branch=master)](https://travis-ci.com/mathildebadoual/hmip)

Solver for large scale nonlinear mixed integer problems.

Developed at [eCAL](https://ecal.berkeley.edu/), UC Berkeley.

# Installation

```bash
pip install hmip
```

# Running

```python
import hmip
```

For examples of how to use the module, run the jupyter notebook /notebooks_examples/examples.ipynb amd read the [Wiki](https://github.com/mathildebadoual/hmip/wiki).

# Contacts:

Mathilde Badoual: mathilde.badoual@berkeley.edu

Bertand Travacca: bertrand.travacca@berkeley.edu
